function mandelbrotcolor(N,Niter,xmin,xmax,ymin,ymax)
%
% mandelbrotcolor(N,Niter,xmin,xmax,ymin,ymax)
%
% Disegna in maniera artistica l'insieme di Mandelbrot della mappa complessa
% z_{n+1} = z_n^2 + c. I punti hanno un colore che dipende dal loro
% valore assoluto una volta raggiunto il numero massimo di iterazioni.
%
% Input:
%   N     Numero di pixel in x e y
%   Niter Numero massimo di iterazioni
%   xmin  Ascissa minima nel plot
%   xmax  Ascissa massima nel plot
%   ymin  Ordinata minima nel plot
%   ymax  Ordinata massima nel plot
%
% Esempio
%
%   mandelbrotbw(100,100,-2,.6,-1.25,1.25)
%
% Altri esempi sono riportati alla fine di questo file. In GNU Octave
% e` possibile lanciarli con
%
% octave:1> demo mandelbrotbw
%
% Copyright (C) 2009 Simone Zuccher
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% Author:   Simone Zuccher <simone.zuccher@univr.it>
% Created:  04 Jul 2009
% Modified:

% Griglia
x = linspace(xmin,xmax,N);
y = linspace(ymin,ymax,N);

% Matrice dei valori di c
[Re,Im] = meshgrid(x,y);
c = Re + 1i*Im;

% Matrice delle condizioni iniziali
z = zeros(size(c));
zplot = z;

% Ciclo
for i = 1:Niter
  zplot = zplot + (abs(z) <= 2);
  z = z.*z + c;
end
% Plot
imagesc(x,y,zplot);
colormap(jet(64))
axis equal
axis off
%!demo
%! mandelbrotcolor(1000,200,-1.9,.6,-1.25,1.25);
%! hold on
%! plot([-1.2,-1.2],[-0.4,0],'k','LineWidth',2)
%! plot([-1.2,-0.6],[-0.4,-0.4],'k','LineWidth',2)
%! plot([-0.6,-0.6],[-0.4,0],'k','LineWidth',2)
%! plot([-1.2,-0.6],[0,0],'k','LineWidth',2)
%! figure
%! mandelbrotcolor(1000,200,-1.2,-0.6,-0.4,0);
%! hold on
%! plot([-0.8,-0.8],[-0.1,-0.05],'k','LineWidth',2)
%! plot([-0.8,-0.73],[-0.1,-0.1],'k','LineWidth',2)
%! plot([-0.73,-0.73],[-0.1,-0.05],'k','LineWidth',2)
%! plot([-0.8,-0.73],[-0.05,-0.05],'k','LineWidth',2)
%! figure
%! mandelbrotcolor(1000,200,-0.8,-0.73,-0.1,-0.05);
%! hold on
%! plot([-0.751,-0.751],[-0.086,-0.081],'k','LineWidth',2)
%! plot([-0.751,-0.744],[-0.086,-0.086],'k','LineWidth',2)
%! plot([-0.744,-0.744],[-0.086,-0.081],'k','LineWidth',2)
%! plot([-0.751,-0.744],[-0.081,-0.081],'k','LineWidth',2)
%! figure
%! mandelbrotcolor(1000,200,-0.751,-0.744,-0.086,-0.081);
%! hold on
%! plot([-0.748,-0.748],[-0.0834,-0.0825],'k','LineWidth',2)
%! plot([-0.748,-0.747],[-0.0834,-0.0834],'k','LineWidth',2)
%! plot([-0.747,-0.747],[-0.0834,-0.0825],'k','LineWidth',2)
%! plot([-0.748,-0.747],[-0.0825,-0.0825],'k','LineWidth',2)
%! figure
%! mandelbrotcolor(1000,200,-0.748,-0.747,-0.0834,-0.0825);
